@@ -1,4 +1,4 @@
-package Alien::xmake 0.02 {
+package Alien::xmake 0.03 {
     use strict;
     use warnings;
     use File::Which qw[which];
@@ -267,7 +267,7 @@ Build from source using gmake instead of make.
 
 =head1 See Also
 
-https://xmake.io/
+L<https://xmake.io/>
 
 =head1 LICENSE
 
